import yaml


class ConnectionType(yaml.YAMLObject):

    yaml_tag = u'!ConnectionType'

    def __init__(self, _name, _url):
        self.name = _name
        self.url = _url

    # GETTERS / SETTERS
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value

    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value



import os


class Paths:
    COBRA_FOLDER = os.path.expanduser("~/.pocr")
    CONF_FILE_PATH = os.path.join(COBRA_FOLDER, "config")
    PROJECT_FILE_PATH = os.path.join(COBRA_FOLDER, "projects")
    PACKAGE_VCS_PATH = '/vcs.yml'
    PACKAGE_GIT_HOOK_PATH = '/'.join(('utils', 'post-commit'))


class Structures:
    # default yaml structure for the config file
    AUTH_SCOPES = ['repo', 'delete_repo']


class Texts:
    VCS_SELECT_TEXT = "Chose the vcs host you want to use (for all projects)"
    CON_SELECT_TEXT = "Select the connection type:"
    USERNAME_TEXT = "Enter your username (of the VCS host)"
    PASSWORD_TEXT = "Enter your password (of the VCS host)"
    AUTH_TEXT = "What kind of Authentication do you want to use: (if 2FA chose token)"
    TOKEN_TEXT = "Enter the token"
    TFA_TEXT = "Enter the 2FA token"
    TOKEN_ALREADY_EXISTS_TEXT = "Token already exists. Please delete the token (https://github.com/settings/tokens)"



from setuptools import setup, find_packages
import os

this_directory = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(name='cobra-projects',
      version='0.1.8alpha0',
      description='A tool to create and maintain your python projects',
      long_description=long_description,
      long_description_content_type='text/markdown',
      url='https://github.com/lvoegtlin/cobra',
      author='Lars Voegtlin',
      author_email='lars.voegtlin@unifr.ch',
      license='MIT',
      packages=find_packages(exclude=['build', 'dist']),
      entry_points={
          'console_scripts': ['cobra=cobra.controller:entry_point'],
      },
      include_package_data=True,
      package_data={'': ['*.yml', 'post-commit']},
      install_requires=['keyring==19.0.1', 'pyyaml==5.1.2', 'PyInquirer==1.0.3', 'prompt_toolkit==1.0.14',
                        'pygithub==1.43.6', 'gitpython==3.0.3', 'tabulate==0.8.5', 'readme-renderer>=21.0'],
      python_requires='>=3.6',
      zip_safe=False)



import os

import git

from cobra.conf.config import Config
from cobra.utils.utils import get_github_user


class ModuleFunctions:

    @staticmethod
    def create_folder(project):
        # pull repo
        print("Pulling the repo...")
        cwd = os.getcwd()
        git_url = "{}{}/{}.git".format(Config.getInstance().connection_type.url, Config.getInstance().username,
                                       project.repo_name)
        git.Git(cwd).clone(git_url)
        print("Pulling done")

    @staticmethod
    def create_repo(project):
        print("Creating a repo...")
        user = get_github_user()
        user.create_repo(project.repo_name, auto_init=True)
        print("Repo creation successful")

    @staticmethod
    def create_environment(project):
        # create conda
        print("Creating conda environment...")
        arguments = ["--name", project.conda_name, "python={}".format(project.python_version)]
        # can not use conda api because it does not work
        os.system("conda create -y {}".format(' '.join(arguments)))

